Class: Samsara::Types::AddressGeofencePolygonVertices

Inherits:
Object
  • Object
show all
Defined in:
lib/samsara_api/types/address_geofence_polygon_vertices.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(latitude:, longitude:, additional_properties: nil) ⇒ Samsara::Types::AddressGeofencePolygonVertices

Parameters:

  • latitude (Float) —

    The latitude of a geofence vertex in decimal degrees.

  • longitude (Float) —

    The longitude of a geofence vertex in decimal degrees.

  • additional_properties (OpenStruct) (defaults to: nil) —

    Additional properties unmapped to the current class definition



24
25
26
27
28
29
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 24

def initialize(latitude:, longitude:, additional_properties: nil)
  @latitude = latitude
  @longitude = longitude
  @additional_properties = additional_properties
  @_field_set = { "latitude": latitude, "longitude": longitude }
end

Instance Attribute Details

#additional_properties ⇒ OpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct) —

    Additional properties unmapped to the current class definition



13
14
15
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 13

def additional_properties
  @additional_properties
end

#latitude ⇒ Float (readonly)

Returns The latitude of a geofence vertex in decimal degrees.

Returns:

  • (Float) —

    The latitude of a geofence vertex in decimal degrees.



9
10
11
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 9

def latitude
  @latitude
end

#longitude ⇒ Float (readonly)

Returns The longitude of a geofence vertex in decimal degrees.

Returns:

  • (Float) —

    The longitude of a geofence vertex in decimal degrees.



11
12
13
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 11

def longitude
  @longitude
end

Class Method Details

.from_json(json_object:) ⇒ Samsara::Types::AddressGeofencePolygonVertices

Parameters:

  • json_object (String)

Returns:



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 34

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  latitude = parsed_json["latitude"]
  longitude = parsed_json["longitude"]
  new(
    latitude: latitude,
    longitude: longitude,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Parameters:

  • obj (Object)

Returns:

  • (Void)


57
58
59
60
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 57

def self.validate_raw(obj:)
  obj.latitude.is_a?(Float) != false || raise("Passed value for field obj.latitude is not the expected type, validation failed.")
  obj.longitude.is_a?(Float) != false || raise("Passed value for field obj.longitude is not the expected type, validation failed.")
end

Instance Method Details

#to_json ⇒ String

Returns:

  • (String)


48
49
50
# File 'lib/samsara_api/types/address_geofence_polygon_vertices.rb', line 48

def to_json
  @_field_set&.to_json
end