Class: Samsara::Types::FuelEnergyCostResponseResponseBody

Inherits:
Object
  • Object
show all
Defined in:
lib/samsara_api/types/fuel_energy_cost_response_response_body.rb

Overview

Estimated cost of fuel and energy over the given time range.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(amount:, currency_code:, additional_properties: nil) ⇒ Samsara::Types::FuelEnergyCostResponseResponseBody

Parameters:

  • amount (Float) —

    Amount of the currency.

  • currency_code (String) —

    Type of the currency.

  • additional_properties (OpenStruct) (defaults to: nil) —

    Additional properties unmapped to the current class definition



25
26
27
28
29
30
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 25

def initialize(amount:, currency_code:, additional_properties: nil)
  @amount = amount
  @currency_code = currency_code
  @additional_properties = additional_properties
  @_field_set = { "amount": amount, "currencyCode": currency_code }
end

Instance Attribute Details

#additional_properties ⇒ OpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct) —

    Additional properties unmapped to the current class definition



14
15
16
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 14

def additional_properties
  @additional_properties
end

#amount ⇒ Float (readonly)

Returns Amount of the currency.

Returns:

  • (Float) —

    Amount of the currency.



10
11
12
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 10

def amount
  @amount
end

#currency_code ⇒ String (readonly)

Returns Type of the currency.

Returns:

  • (String) —

    Type of the currency.



12
13
14
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 12

def currency_code
  @currency_code
end

Class Method Details

.from_json(json_object:) ⇒ Samsara::Types::FuelEnergyCostResponseResponseBody

Parameters:

  • json_object (String)

Returns:



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 35

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  amount = parsed_json["amount"]
  currency_code = parsed_json["currencyCode"]
  new(
    amount: amount,
    currency_code: currency_code,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Parameters:

  • obj (Object)

Returns:

  • (Void)


58
59
60
61
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 58

def self.validate_raw(obj:)
  obj.amount.is_a?(Float) != false || raise("Passed value for field obj.amount is not the expected type, validation failed.")
  obj.currency_code.is_a?(String) != false || raise("Passed value for field obj.currency_code is not the expected type, validation failed.")
end

Instance Method Details

#to_json ⇒ String

Returns:

  • (String)


49
50
51
# File 'lib/samsara_api/types/fuel_energy_cost_response_response_body.rb', line 49

def to_json
  @_field_set&.to_json
end