Class: Samsara::Types::V1Message

Inherits:
Object
  • Object
show all
Defined in:
lib/samsara_api/types/v_1_message.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(driver_id:, text:, additional_properties: nil) ⇒ Samsara::Types::V1Message

Parameters:

  • driver_id (Long) —

    ID of the driver for whom the message is sent to or sent by.

  • text (String) —

    The text sent in the message.

  • additional_properties (OpenStruct) (defaults to: nil) —

    Additional properties unmapped to the current class definition



24
25
26
27
28
29
# File 'lib/samsara_api/types/v_1_message.rb', line 24

def initialize(driver_id:, text:, additional_properties: nil)
  @driver_id = driver_id
  @text = text
  @additional_properties = additional_properties
  @_field_set = { "driverId": driver_id, "text": text }
end

Instance Attribute Details

#additional_properties ⇒ OpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct) —

    Additional properties unmapped to the current class definition



13
14
15
# File 'lib/samsara_api/types/v_1_message.rb', line 13

def additional_properties
  @additional_properties
end

#driver_id ⇒ Long (readonly)

Returns ID of the driver for whom the message is sent to or sent by.

Returns:

  • (Long) —

    ID of the driver for whom the message is sent to or sent by.



9
10
11
# File 'lib/samsara_api/types/v_1_message.rb', line 9

def driver_id
  @driver_id
end

#text ⇒ String (readonly)

Returns The text sent in the message.

Returns:

  • (String) —

    The text sent in the message.



11
12
13
# File 'lib/samsara_api/types/v_1_message.rb', line 11

def text
  @text
end

Class Method Details

.from_json(json_object:) ⇒ Samsara::Types::V1Message

Parameters:

  • json_object (String)

Returns:



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/samsara_api/types/v_1_message.rb', line 34

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  driver_id = parsed_json["driverId"]
  text = parsed_json["text"]
  new(
    driver_id: driver_id,
    text: text,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Parameters:

  • obj (Object)

Returns:

  • (Void)


57
58
59
60
# File 'lib/samsara_api/types/v_1_message.rb', line 57

def self.validate_raw(obj:)
  obj.driver_id.is_a?(Long) != false || raise("Passed value for field obj.driver_id is not the expected type, validation failed.")
  obj.text.is_a?(String) != false || raise("Passed value for field obj.text is not the expected type, validation failed.")
end

Instance Method Details

#to_json ⇒ String

Returns:

  • (String)


48
49
50
# File 'lib/samsara_api/types/v_1_message.rb', line 48

def to_json
  @_field_set&.to_json
end