Class: Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatus
- Inherits:
-
Object
- Object
- Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatus
- Defined in:
- lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb
Overview
Readings from engine sensors
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
- #catalyst ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #comprehensive ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #egr ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #evap_system ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #fuel ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #heated_catalyst ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #heated_o_2_sensor ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #iso_sae_reserved ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #misfire ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
-
#not_ready_count ⇒ Integer
readonly
Count of the number of sensors reporting N: Not Complete.
- #o_2_sensor ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
- #secondary_air ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue readonly
Class Method Summary collapse
- .from_json(json_object:) ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatus
- .validate_raw(obj:) ⇒ Void
Instance Method Summary collapse
- #initialize(catalyst: OMIT, comprehensive: OMIT, egr: OMIT, evap_system: OMIT, fuel: OMIT, heated_catalyst: OMIT, heated_o_2_sensor: OMIT, iso_sae_reserved: OMIT, misfire: OMIT, not_ready_count: OMIT, o_2_sensor: OMIT, secondary_air: OMIT, additional_properties: nil) ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatus constructor
- #to_json ⇒ String
Constructor Details
#initialize(catalyst: OMIT, comprehensive: OMIT, egr: OMIT, evap_system: OMIT, fuel: OMIT, heated_catalyst: OMIT, heated_o_2_sensor: OMIT, iso_sae_reserved: OMIT, misfire: OMIT, not_ready_count: OMIT, o_2_sensor: OMIT, secondary_air: OMIT, additional_properties: nil) ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatus
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 56 def initialize(catalyst: OMIT, comprehensive: OMIT, egr: OMIT, evap_system: OMIT, fuel: OMIT, heated_catalyst: OMIT, heated_o_2_sensor: OMIT, iso_sae_reserved: OMIT, misfire: OMIT, not_ready_count: OMIT, o_2_sensor: OMIT, secondary_air: OMIT, additional_properties: nil) @catalyst = catalyst if catalyst != OMIT @comprehensive = comprehensive if comprehensive != OMIT @egr = egr if egr != OMIT @evap_system = evap_system if evap_system != OMIT @fuel = fuel if fuel != OMIT @heated_catalyst = heated_catalyst if heated_catalyst != OMIT @heated_o_2_sensor = heated_o_2_sensor if heated_o_2_sensor != OMIT @iso_sae_reserved = iso_sae_reserved if iso_sae_reserved != OMIT @misfire = misfire if misfire != OMIT @not_ready_count = not_ready_count if not_ready_count != OMIT @o_2_sensor = o_2_sensor if o_2_sensor != OMIT @secondary_air = secondary_air if secondary_air != OMIT @additional_properties = additional_properties @_field_set = { "catalyst": catalyst, "comprehensive": comprehensive, "egr": egr, "evapSystem": evap_system, "fuel": fuel, "heatedCatalyst": heated_catalyst, "heatedO2Sensor": heated_o_2_sensor, "isoSaeReserved": iso_sae_reserved, "misfire": misfire, "notReadyCount": not_ready_count, "o2Sensor": o_2_sensor, "secondaryAir": secondary_air }.reject do | _k, v | v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
35 36 37 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 35 def additional_properties @additional_properties end |
#catalyst ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
11 12 13 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 11 def catalyst @catalyst end |
#comprehensive ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
13 14 15 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 13 def comprehensive @comprehensive end |
#egr ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
15 16 17 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 15 def egr @egr end |
#evap_system ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
17 18 19 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 17 def evap_system @evap_system end |
#fuel ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
19 20 21 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 19 def fuel @fuel end |
#heated_catalyst ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
21 22 23 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 21 def heated_catalyst @heated_catalyst end |
#heated_o_2_sensor ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
23 24 25 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 23 def heated_o_2_sensor @heated_o_2_sensor end |
#iso_sae_reserved ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
25 26 27 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 25 def iso_sae_reserved @iso_sae_reserved end |
#misfire ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
27 28 29 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 27 def misfire @misfire end |
#not_ready_count ⇒ Integer (readonly)
Returns Count of the number of sensors reporting N: Not Complete.
29 30 31 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 29 def not_ready_count @not_ready_count end |
#o_2_sensor ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
31 32 33 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 31 def o_2_sensor @o_2_sensor end |
#secondary_air ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue (readonly)
33 34 35 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 33 def secondary_air @secondary_air end |
Class Method Details
.from_json(json_object:) ⇒ Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatus
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 79 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) catalyst = parsed_json["catalyst"] comprehensive = parsed_json["comprehensive"] egr = parsed_json["egr"] evap_system = parsed_json["evapSystem"] fuel = parsed_json["fuel"] heated_catalyst = parsed_json["heatedCatalyst"] heated_o_2_sensor = parsed_json["heatedO2Sensor"] iso_sae_reserved = parsed_json["isoSaeReserved"] misfire = parsed_json["misfire"] not_ready_count = parsed_json["notReadyCount"] o_2_sensor = parsed_json["o2Sensor"] secondary_air = parsed_json["secondaryAir"] new( catalyst: catalyst, comprehensive: comprehensive, egr: egr, evap_system: evap_system, fuel: fuel, heated_catalyst: heated_catalyst, heated_o_2_sensor: heated_o_2_sensor, iso_sae_reserved: iso_sae_reserved, misfire: misfire, not_ready_count: not_ready_count, o_2_sensor: o_2_sensor, secondary_air: secondary_air, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 123 def self.validate_raw(obj:) obj.catalyst&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.catalyst is not the expected type, validation failed.") obj.comprehensive&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.comprehensive is not the expected type, validation failed.") obj.egr&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.egr is not the expected type, validation failed.") obj.evap_system&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.evap_system is not the expected type, validation failed.") obj.fuel&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.fuel is not the expected type, validation failed.") obj.heated_catalyst&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.heated_catalyst is not the expected type, validation failed.") obj.heated_o_2_sensor&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.heated_o_2_sensor is not the expected type, validation failed.") obj.iso_sae_reserved&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.iso_sae_reserved is not the expected type, validation failed.") obj.misfire&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.misfire is not the expected type, validation failed.") obj.not_ready_count&.is_a?(Integer) != false || raise("Passed value for field obj.not_ready_count is not the expected type, validation failed.") obj.o_2_sensor&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.o_2_sensor is not the expected type, validation failed.") obj.secondary_air&.is_a?(Samsara::Types::VehicleStatsFaultCodesPassengerMonitorStatusValue) != false || raise("Passed value for field obj.secondary_air is not the expected type, validation failed.") end |
Instance Method Details
#to_json ⇒ String
114 115 116 |
# File 'lib/samsara_api/types/vehicle_stats_fault_codes_passenger_monitor_status.rb', line 114 def to_json @_field_set&.to_json end |