Class: Samsara::Types::EnumValueResponseBody
- Inherits:
-
Object
- Object
- Samsara::Types::EnumValueResponseBody
- Defined in:
- lib/samsara_api/types/enum_value_response_body.rb
Overview
Enumeration value
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#label ⇒ Object
readonly
english.
-
#symbol ⇒ String
readonly
The symbol that can be used to represent this enumeration value.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(label:, symbol:, additional_properties: nil) ⇒ Samsara::Types::EnumValueResponseBody constructor
- #to_json ⇒ String
Constructor Details
#initialize(label:, symbol:, additional_properties: nil) ⇒ Samsara::Types::EnumValueResponseBody
27 28 29 30 31 32 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 27 def initialize(label:, symbol:, additional_properties: nil) @label = label @symbol = symbol @additional_properties = additional_properties @_field_set = { "label": label, "symbol": symbol } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
15 16 17 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 15 def additional_properties @additional_properties end |
#label ⇒ Object (readonly)
english.
11 12 13 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 11 def label @label end |
#symbol ⇒ String (readonly)
Returns The symbol that can be used to represent this enumeration value.
13 14 15 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 13 def symbol @symbol end |
Class Method Details
.from_json(json_object:) ⇒ Samsara::Types::EnumValueResponseBody
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 37 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) label = parsed_json["label"] symbol = parsed_json["symbol"] new( label: label, symbol: symbol, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
60 61 62 63 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 60 def self.validate_raw(obj:) obj.label.is_a?(String) != false || raise("Passed value for field obj.label is not the expected type, validation failed.") obj.symbol.is_a?(String) != false || raise("Passed value for field obj.symbol is not the expected type, validation failed.") end |
Instance Method Details
#to_json ⇒ String
51 52 53 |
# File 'lib/samsara_api/types/enum_value_response_body.rb', line 51 def to_json @_field_set&.to_json end |