Class: Samsara::Types::V1Message
- Inherits:
-
Object
- Object
- Samsara::Types::V1Message
- Defined in:
- lib/samsara_api/types/v_1_message.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#driver_id ⇒ Long
readonly
ID of the driver for whom the message is sent to or sent by.
-
#text ⇒ String
readonly
The text sent in the message.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(driver_id:, text:, additional_properties: nil) ⇒ Samsara::Types::V1Message constructor
- #to_json ⇒ String
Constructor Details
#initialize(driver_id:, text:, additional_properties: nil) ⇒ Samsara::Types::V1Message
24 25 26 27 28 29 |
# File 'lib/samsara_api/types/v_1_message.rb', line 24 def initialize(driver_id:, text:, additional_properties: nil) @driver_id = driver_id @text = text @additional_properties = additional_properties @_field_set = { "driverId": driver_id, "text": text } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
13 14 15 |
# File 'lib/samsara_api/types/v_1_message.rb', line 13 def additional_properties @additional_properties end |
#driver_id ⇒ Long (readonly)
Returns ID of the driver for whom the message is sent to or sent by.
9 10 11 |
# File 'lib/samsara_api/types/v_1_message.rb', line 9 def driver_id @driver_id end |
#text ⇒ String (readonly)
Returns The text sent in the message.
11 12 13 |
# File 'lib/samsara_api/types/v_1_message.rb', line 11 def text @text end |
Class Method Details
.from_json(json_object:) ⇒ Samsara::Types::V1Message
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/samsara_api/types/v_1_message.rb', line 34 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) driver_id = parsed_json["driverId"] text = parsed_json["text"] new( driver_id: driver_id, text: text, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
57 58 59 60 |
# File 'lib/samsara_api/types/v_1_message.rb', line 57 def self.validate_raw(obj:) obj.driver_id.is_a?(Long) != false || raise("Passed value for field obj.driver_id is not the expected type, validation failed.") obj.text.is_a?(String) != false || raise("Passed value for field obj.text is not the expected type, validation failed.") end |
Instance Method Details
#to_json ⇒ String
48 49 50 |
# File 'lib/samsara_api/types/v_1_message.rb', line 48 def to_json @_field_set&.to_json end |