Class: Samsara::Types::V1MessageSender
- Inherits:
-
Object
- Object
- Samsara::Types::V1MessageSender
- Defined in:
- lib/samsara_api/types/v_1_message_sender.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#name ⇒ String
readonly
Name of user that is sending the message.
-
#type ⇒ String
readonly
Type of user that is sending the message.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(name:, type:, additional_properties: nil) ⇒ Samsara::Types::V1MessageSender constructor
- #to_json ⇒ String
Constructor Details
#initialize(name:, type:, additional_properties: nil) ⇒ Samsara::Types::V1MessageSender
24 25 26 27 28 29 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 24 def initialize(name:, type:, additional_properties: nil) @name = name @type = type @additional_properties = additional_properties @_field_set = { "name": name, "type": type } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
13 14 15 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 13 def additional_properties @additional_properties end |
#name ⇒ String (readonly)
Returns Name of user that is sending the message.
9 10 11 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 9 def name @name end |
#type ⇒ String (readonly)
Returns Type of user that is sending the message. It will be either dispatch or driver.
11 12 13 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 11 def type @type end |
Class Method Details
.from_json(json_object:) ⇒ Samsara::Types::V1MessageSender
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 34 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) name = parsed_json["name"] type = parsed_json["type"] new( name: name, type: type, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
57 58 59 60 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 57 def self.validate_raw(obj:) obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.type.is_a?(String) != false || raise("Passed value for field obj.type is not the expected type, validation failed.") end |
Instance Method Details
#to_json ⇒ String
48 49 50 |
# File 'lib/samsara_api/types/v_1_message_sender.rb', line 48 def to_json @_field_set&.to_json end |